@@ -169,7 +169,7 @@ public class PriorListInputEditor extends ListInputEditor {
                 "," + (upper == null ? "\u221E" : upper + "") + "]";
     }
 
-    Set<Taxon> getTaxonCandidates(MRCAPrior prior) {
+    protected Set<Taxon> getTaxonCandidates(MRCAPrior prior) {
         Set<Taxon> candidates = new HashSet<>();
         Tree tree = prior.treeInput.get();
         String [] taxa = null;
