@@ -50,7 +50,7 @@ import beast.core.BEASTInterface;
 import beast.core.Input;
 import beast.core.Runnable;
 import beast.core.util.Log;
-import beast.util.AddOnManager;
+import beast.util.PackageManager;
 import beast.util.XMLParser;
 import beast.util.XMLProducer;
 
@@ -104,7 +104,7 @@ public class Document {
 
     public Document() {
         // load all parsers
-        List<String> plugInNames = AddOnManager.find(beast.core.BEASTInterface.class, AddOnManager.IMPLEMENTATION_DIR);
+        List<String> plugInNames = PackageManager.find(beast.core.BEASTInterface.class, PackageManager.IMPLEMENTATION_DIR);
         m_sPlugInNames = plugInNames.toArray(new String[0]);
         tabulist = new HashSet<>();
         Properties properties = new Properties();
