@@ -1,48 +1,130 @@
 package beast.core.parameter;
 
-import java.io.PrintStream;
-import java.lang.reflect.Array;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-
-import org.w3c.dom.NamedNodeMap;
-import org.w3c.dom.Node;
-
 import beast.core.Description;
 import beast.core.Function;
 import beast.core.Input;
 import beast.core.StateNode;
+import org.w3c.dom.NamedNodeMap;
+import org.w3c.dom.Node;
+
+import java.io.PrintStream;
+import java.lang.reflect.Array;
+import java.util.*;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 public interface Parameter<T> extends Function {
 
-    public T getValue(int i);
+    T getValue(int i);
 
-    public T getValue();
+    T getValue();
 
-    public void setValue(int i, T value);
-    
-    public void setValue(T value);
+    void setValue(int i, T value);
 
-    public T getLower();
+    void setValue(T value);
 
-    public void setLower(final T lower);
+    T getLower();
 
-    public T getUpper();
+    void setLower(final T lower);
 
-    public void setUpper(final T upper);
+    T getUpper();
 
-    public T[] getValues();
+    void setUpper(final T upper);
 
-    public String getID();
+    T[] getValues();
 
-    public int getMinorDimension1();
+    String getID();
 
-    public int getMinorDimension2();
+    /**
+     * @return the number of columns
+     */
+    int getMinorDimension1();
 
-    public T getMatrixValue(int i, int j);
+    /**
+     * @return the number of rows
+     */
+    int getMinorDimension2();
+
+    default int getColumnCount() {
+        return getMinorDimension1();
+    }
+
+    default int getRowCount() {
+        return getMinorDimension2();
+    }
+
+    /**
+     * Interprets the parameter as a two dimensional matrix, with minorDimension1 column width.
+     *
+     * @param row zero-based row index
+     * @param column zero-based column index
+     * @return
+     */
+    default T getMatrixValue(int row, int column) {
+        return getValue(row * getColumnCount() + column);
+    }
+
+    default T[] getRowValues(String key) {
+        List<String> keys = getKeysList();
+        if (keys.size() == getRowCount()) {
+            for (int row = 0; row < keys.size(); row++) {
+                if (keys.get(row).equals(key)) {
+                    return getRowValues(row);
+                }
+            }
+        }
+        return null;
+    }
+
+    default T[] getRowValues(int row) {
+
+        T firstVal = getMatrixValue(row,0);
+
+        T[] values = (T[])Array.newInstance(firstVal.getClass(), getColumnCount());
+        values[0] = firstVal;
+        for (int column = 1; column < getColumnCount(); column++) {
+            values[column] = getMatrixValue(row, column);
+        }
+        return values;
+    }
+
+    /**
+     * @param i index
+     * @return the unique key for the i'th value.
+     *         Default implementation will return a string representing the zero-based index,
+     *         (i.e. a string representation of the argument).
+     */
+    default String getKey(int i) {
+        if (getDimension() == 1) return "0";
+        else if (i < getDimension()) return "" + (i+1);
+        throw new IllegalArgumentException("Invalid index " + i);
+    }
+
+    /**
+     * @param key unique key for a value
+     * @return the value associated with that key, or null
+     */
+    default T getValue(String key) {
+        try {
+            int index = Integer.parseInt(key);
+            return getValue(index);
+        } catch (NumberFormatException nfe) {
+            return null;
+        }
+    }
+
+    /**
+     * @return the unmodifiable list of keys (a unique string for each dimension)
+     *         that parallels the parameter index.
+     *         It will throw UnsupportedOperationException if attempting to modify.
+     */
+    default List<String> getKeysList() {
+        List<String> keys = new ArrayList<>();
+        for (int i = 0; i < getDimension(); i++) {
+            keys.add(getKey(i));
+        }
+        return Collections.unmodifiableList(keys);
+    }
 
     /**
      * swap values of element i and j
@@ -50,11 +132,10 @@ public interface Parameter<T> extends Function {
      * @param i
      * @param j
      */
-    public void swap(int i, int j);
+    void swap(int i, int j);
 
-    @Description("A parameter represents a value in the state space that can be changed "
-            + "by operators.")
-    public abstract class Base<T> extends StateNode implements Parameter<T> {
+    @Description("A parameter represents a value in the state space that can be changed by operators.")
+    abstract class Base<T> extends StateNode implements Parameter<T> {
 
         /**
          * value is a required input since it is very hard to ensure any
@@ -67,6 +148,8 @@ public interface Parameter<T> extends Function {
                 new Input<>("dimension", "dimension of the parameter (default 1, i.e scalar)", 1);
         public final Input<Integer> minorDimensionInput = new Input<>("minordimension", "minor-dimension when the parameter is interpreted as a matrix (default 1)", 1);
 
+        public final Input<String> keysInput = new Input<>("keys", "the keys (unique dimension names) for the dimensions of this parameter", (String) null);
+
         /**
          * constructors *
          */
@@ -80,12 +163,12 @@ public interface Parameter<T> extends Function {
             m_fLower = getMin();
             m_bIsDirty = new boolean[values.length];
             for (T value : values) {
-            	valuesInput.get().add(value);
+                valuesInput.get().add(value);
             }
         }
 
         @SuppressWarnings("unchecked")
-		@Override
+        @Override
         public void initAndValidate() {
             T[] valuesString = valuesInput.get().toArray((T[]) Array.newInstance(getMax().getClass(), 0));
 
@@ -104,7 +187,44 @@ public interface Parameter<T> extends Function {
                 throw new IllegalArgumentException("Dimension must be divisible by stride");
             }
             this.storedValues = values.clone();
+
+            if (keysInput.get() != null) {
+                String[] keysArr = keysInput.get().split(" ");
+                // unmodifiable list : UnsupportedOperationException if attempting to modify
+                List<String> keys = Collections.unmodifiableList(Arrays.asList(keysArr));
+
+                // getRowCount() = getDimension() / minorDimension, getColumnCount() = minorDimension
+                if (getColumnCount() > 1) { // 2-D matrix
+                    if (! (keys.size() == getDimension() || keys.size() == getRowCount()) )
+                        throw new IllegalArgumentException("For 2D matrix, keys must either have the same length " +
+                                "as dimension or the number of rows ! Number of rows = " +
+                                getRowCount() + ", but keys.size() = " + keys.size());
+                } else { // 1-D array
+                    if (keys.size() != getDimension())
+                        throw new IllegalArgumentException("For 1D array, keys must have the same length as dimension ! " +
+                                "Dimension = " + getDimension() + ", but keys.size() = " + keys.size());
+                }
+
+                initKeys(keys);
+            }
         }
+
+        private void initKeys(List<String> keys) {
+            this.keys = keys;
+
+            if (keys != null) {
+                keyToIndexMap = new TreeMap<>();
+                for (int i = 0; i < keys.size(); i++) {
+                    keyToIndexMap.put(keys.get(i), i);
+                }
+                if (keyToIndexMap.keySet().size() != keys.size()) {
+                    throw new IllegalArgumentException("All keys must be unique! Found " +
+                            keyToIndexMap.keySet().size() + " unique keys for " + getDimension() + " dimensions.");
+                }
+            }
+        }
+
+
         /**
          * upper & lower bound These are located before the inputs (instead of
          * after the inputs, as usual) so that valuesInput can determines the
@@ -116,6 +236,7 @@ public interface Parameter<T> extends Function {
         abstract T getMax();
 
         abstract T getMin();
+
         /**
          * the actual values of this parameter
          */
@@ -134,6 +255,49 @@ public interface Parameter<T> extends Function {
          */
         protected int m_nLastDirty;
 
+        private List<String> keys = null; // unmodifiableList
+        private java.util.Map<String, Integer> keyToIndexMap = null;
+
+        /**
+         * @param i index
+         * @return the unique key for the i'th value.
+         */
+        public String getKey(int i) {
+            if (keys != null) return keys.get(i);
+            return Parameter.super.getKey(i);
+        }
+
+        /**
+         * @param key unique key for a value
+         * @return the value associated with that key, or null
+         */
+        public T getValue(String key) {
+            if (keys != null) {
+                return getValue(keyToIndexMap.get(key));
+            }
+            return Parameter.super.getValue(key);
+        }
+
+        /**
+         * Please use {@link #getKeysList}
+         * @return a sorted set of valid keys for this parameter.
+         */
+        @Deprecated
+        public String[] getKeys() {
+            if (keys != null) return keys.toArray(new String[0]);
+            return Parameter.super.getKeysList().toArray(new String[0]);
+        }
+
+        /**
+         * @return the unmodifiable list of keys (a unique string for each dimension)
+         *         that parallels the parameter index.
+         *         It will throw UnsupportedOperationException if attempting to modify
+         */
+        public List<String> getKeysList() {
+            if (keys != null) return keys; // unmodifiable list
+            return Parameter.super.getKeysList();
+        }
+
         /**
          * @param index dimension to check
          * @return true if the param-th element has changed
@@ -233,7 +397,7 @@ public interface Parameter<T> extends Function {
         public T getStoredValue(final int param) {
             return storedValues[param];
         }
-        
+
         @Override
         public T[] getValues() {
             return Arrays.copyOf(values, values.length);
@@ -241,6 +405,7 @@ public interface Parameter<T> extends Function {
 
         /**
          * Copies this parameters values to the given array
+         *
          * @param copyTo
          */
         public void getValues(T[] copyTo) {
@@ -303,8 +468,7 @@ public interface Parameter<T> extends Function {
         @Override
         public Base<T> copy() {
             try {
-                @SuppressWarnings("unchecked")
-                final Parameter.Base<T> copy = (Parameter.Base<T>) this.clone();
+                @SuppressWarnings("unchecked") final Parameter.Base<T> copy = (Parameter.Base<T>) this.clone();
                 copy.values = values.clone();//new Boolean[values.length];
                 copy.m_bIsDirty = new boolean[values.length];
                 return copy;
@@ -316,8 +480,7 @@ public interface Parameter<T> extends Function {
 
         @Override
         public void assignTo(final StateNode other) {
-            @SuppressWarnings("unchecked")
-            final Parameter.Base<T> copy = (Parameter.Base<T>) other;
+            @SuppressWarnings("unchecked") final Parameter.Base<T> copy = (Parameter.Base<T>) other;
             copy.setID(getID());
             copy.index = index;
             copy.values = values.clone();
@@ -329,8 +492,7 @@ public interface Parameter<T> extends Function {
 
         @Override
         public void assignFrom(final StateNode other) {
-            @SuppressWarnings("unchecked")
-            final Parameter.Base<T> source = (Parameter.Base<T>) other;
+            @SuppressWarnings("unchecked") final Parameter.Base<T> source = (Parameter.Base<T>) other;
             setID(source.getID());
             values = source.values.clone();
             storedValues = source.storedValues.clone();
@@ -342,8 +504,7 @@ public interface Parameter<T> extends Function {
 
         @Override
         public void assignFromFragile(final StateNode other) {
-            @SuppressWarnings("unchecked")
-            final Parameter.Base<T> source = (Parameter.Base<T>) other;
+            @SuppressWarnings("unchecked") final Parameter.Base<T> source = (Parameter.Base<T>) other;
             System.arraycopy(source.values, 0, values, 0, Math.min(values.length, source.getDimension()));
             Arrays.fill(m_bIsDirty, false);
         }
@@ -359,7 +520,7 @@ public interface Parameter<T> extends Function {
                 out.print(getID() + "\t");
             } else {
                 for (int value = 0; value < valueCount; value++) {
-                    out.print(getID() + (value + 1) + "\t");
+                    out.print(getID() + "." + getKey(value) + "\t");
                 }
             }
         }
@@ -411,9 +572,9 @@ public interface Parameter<T> extends Function {
          * a template method since it requires creation of an array of T...
          *
          * @param dimension parameter dimension
-         * @param lower lower bound
-         * @param upper upper bound
-         * @param values values
+         * @param lower     lower bound
+         * @param upper     upper bound
+         * @param values    values
          */
         abstract void fromXML(int dimension, String lower, String upper, String[] values);
 
