@@ -186,14 +186,21 @@ public class FilteredAlignment extends Alignment {
         
         // convert data to transposed int array
         int[][] data = new int[nrOfSites][nrOfTaxa];
+        String missingChar = Character.toString(DataType.MISSING_CHAR);
+        String gapChar = Character.toString(DataType.GAP_CHAR);
         for (int i = 0; i < nrOfTaxa; i++) {
             List<Integer> sites = counts.get(i);
             for (int j = 0; j < nrOfSites; j++) {
                 data[j][i] = sites.get(filter[j]);
                 if (convertDataType) {
                 	try {
-                		String code = baseType.getCharacter(data[j][i]);
-						data[j][i] = m_dataType.stringToEncoding(code).get(0);
+                		boolean needsBrackets = baseType.isAmbiguousCode(data[j][i]) && 
+                				! baseType.getCharacter(data[j][i]).equals(missingChar) &&
+                				! baseType.getCharacter(data[j][i]).equals(gapChar);
+            			String code = needsBrackets ?
+            					"{"+baseType.getCharacter(data[j][i]) + "}" :
+            						baseType.getCharacter(data[j][i]);
+            			data[j][i] = m_dataType.stringToEncoding(code).get(0);
                 	} catch (Exception e) {
                 		e.printStackTrace();
                 	}
@@ -301,7 +308,13 @@ public class FilteredAlignment extends Alignment {
                 sites[j] = counts.get(j).get(filter[i]);
                 if (convertDataType) {
                 	try {
-                		sites[j] = m_dataType.stringToEncoding(baseType.getCharacter(sites[j])).get(0);
+                		boolean needsBrackets = baseType.isAmbiguousCode(sites[j]) && 
+                				! baseType.getCharacter(sites[j]).equals(missingChar) &&
+                				! baseType.getCharacter(sites[j]).equals(gapChar);                		
+            			String code = needsBrackets ?
+            					"{"+baseType.getCharacter(sites[j]) + "}" :
+            						baseType.getCharacter(sites[j]);
+            			sites[j] = m_dataType.stringToEncoding(code).get(0);
                 	} catch (Exception e) {
                 		e.printStackTrace();
                 	}
@@ -329,7 +342,14 @@ public class FilteredAlignment extends Alignment {
         //for (int i = 0; i < m_sTaxaNames.size(); i++) {
         //    System.err.println(m_sTaxaNames.get(i) + ": " + m_counts.get(i).size() + " " + m_nStateCounts.get(i));
         //}
-        Log.info.println("Filter " + filterInput.get());
+        
+        String filterText = filterInput.get();
+        if (filterText.length() <= 200) {
+        	Log.info.println("Filter " + filterInput.get());
+        } else {
+        	Log.info.println("Filter " + filterInput.get().substring(0,200) + "...");        	
+        }
+        Log.debug.println("Filter " + filterInput.get());
         Log.info.println(getTaxonCount() + " taxa");
         if (constantSiteWeightsInput.get() != null) {
         	Integer [] constantWeights = constantSiteWeightsInput.get().getValues();
