@@ -63,6 +63,7 @@ public class TreeLikelihood extends GenericTreeLikelihood {
      * calculation engine *
      */
     protected LikelihoodCore likelihoodCore;
+    public LikelihoodCore getLikelihoodCore() {return likelihoodCore;}
     protected BeagleTreeLikelihood beagle;
 
     /**
@@ -73,6 +74,7 @@ public class TreeLikelihood extends GenericTreeLikelihood {
     protected SiteModel.Base m_siteModel;
     protected BranchRateModel.Base branchRateModel;
 
+    public SubstitutionModel getSubstitutionModel() {return substitutionModel;}
     /**
      * flag to indicate the
      * // when CLEAN=0, nothing needs to be recalculated for the node
@@ -117,14 +119,28 @@ public class TreeLikelihood extends GenericTreeLikelihood {
      * dealing with proportion of site being invariant *
      */
     double proportionInvariant = 0;
-    List<Integer> constantPattern = null;
+    public double getProportionInvariant() {return proportionInvariant;}
+	public void setProportionInvariant(double proportionInvariant) {this.proportionInvariant = proportionInvariant;
+	}
+	List<Integer> constantPattern = null;
+	public List<Integer> getConstantPattern() {return constantPattern;}
+    public void setConstantPattern(List<Integer> constantPattern) {this.constantPattern = constantPattern;}
 
     @Override
     public void initAndValidate() {
         // sanity check: alignment should have same #taxa as tree
-        if (dataInput.get().getTaxonCount() != treeInput.get().getLeafNodeCount()) {
-            throw new IllegalArgumentException("The number of nodes in the tree does not match the number of sequences");
-        }
+		
+		if (dataInput.get().getTaxonCount() != treeInput.get().getLeafNodeCount()) {
+			String leaves = "?";
+			if (treeInput.get() instanceof Tree) {
+				leaves = String.join(", ", ((Tree) treeInput.get()).getTaxaNames());
+			}
+			throw new IllegalArgumentException(String.format(
+					"The number of leaves in the tree (%d) does not match the number of sequences (%d). "
+							+ "The tree has leaves [%s], while the data refers to taxa [%s].",
+					treeInput.get().getLeafNodeCount(), dataInput.get().getTaxonCount(),
+					leaves, String.join(", ", dataInput.get().getTaxaNames())));
+		}
         beagle = null;
         beagle = new BeagleTreeLikelihood();
         try {
@@ -160,11 +176,7 @@ public class TreeLikelihood extends GenericTreeLikelihood {
 
         int stateCount = dataInput.get().getMaxStateCount();
         int patterns = dataInput.get().getPatternCount();
-        if (stateCount == 4) {
-            likelihoodCore = new BeerLikelihoodCore4();
-        } else {
-            likelihoodCore = new BeerLikelihoodCore(stateCount);
-        }
+        likelihoodCore = createLikelihoodCore(stateCount);
 
         String className = getClass().getSimpleName();
 
@@ -193,6 +205,14 @@ public class TreeLikelihood extends GenericTreeLikelihood {
         }
     }
 
+    protected LikelihoodCore createLikelihoodCore(int stateCount) {
+		if (stateCount == 4) {
+			return new BeerLikelihoodCore4();
+		} else {
+			return new BeerLikelihoodCore(stateCount);
+		}
+    }
+
 
     /**
      * Determine indices of m_fRootProbabilities that need to be updates
@@ -202,7 +222,7 @@ public class TreeLikelihood extends GenericTreeLikelihood {
      * // taking ambiguities in account, there is a contribution of 1 from
      * // the 'site invariant' category.
      */
-    void calcConstantPatternIndices(final int patterns, final int stateCount) {
+    protected void calcConstantPatternIndices(final int patterns, final int stateCount) {
         constantPattern = new ArrayList<>();
         for (int i = 0; i < patterns; i++) {
             final int[] pattern = dataInput.get().getPattern(i);
@@ -401,7 +421,7 @@ public class TreeLikelihood extends GenericTreeLikelihood {
     }
 
     /* Assumes there IS a branch rate model as opposed to traverse() */
-    int traverse(final Node node) {
+    protected int traverse(final Node node) {
 
         int update = (node.isDirty() | hasDirt);
 
