@@ -174,6 +174,16 @@ public class MRCAPrior extends Distribution {
 
     // would be nice to use nodeRef's, but they are not preserved :(
     public Node getCommonAncestor() {
+        if (!initialised) {
+            initialise();
+        }
+        nodesTraversed = new boolean[tree.getNodeCount()];
+        Node n = getCommonAncestorInternal();
+        assert ! (useRoot && !n.isRoot() ) ;
+        return n;
+    }
+
+    private Node getCommonAncestorInternal() {
         Node cur = tree.getNode(taxonIndex[0]);
 
         for (int k = 1; k < taxonIndex.length; ++k) {
@@ -214,7 +224,6 @@ public class MRCAPrior extends Distribution {
             		isMonophyletic = true;
             		m = tree.getNode(taxonIndex[0]);
             	} else {
-	                nodesTraversed = new boolean[tree.getNodeCount()];
 	                nseen = 0;
                 	m = getCommonAncestor();
 	                isMonophyletic = (nseen == 2 * taxonIndex.length - 1);
@@ -366,12 +375,14 @@ public class MRCAPrior extends Distribution {
             if (dist != null) {
                 out.print("logP(mrca(" + taxonsetInput.get().getID() + "))\t");
             }
-            out.print("mrcatime(" + taxonsetInput.get().getID() + (useOriginate ? ".originate" : "") +")\t");
+            // this is sometimes a date and sometimes an age -- we need to be more explicit in the name.
+            // This is also a problem in BEAUti when specifying an MRCAPrior
+            out.print("mrca." + tree.getDateType() + "(" + taxonsetInput.get().getID() + (useOriginate ? ".originate" : "") +")\t");
         }
     }
 
     @Override
-    public void log(final int sample, final PrintStream out) {
+    public void log(final long sample, final PrintStream out) {
         if (onlyUseTips) {
             if (dist != null) {
                 out.print(getCurrentLogP() + "\t");
