@@ -156,9 +156,6 @@ public class PackageManager {
      * @throws java.net.MalformedURLException
      */
     public static List<URL> getRepositoryURLs() throws MalformedURLException {
-        // Java 7 introduced SNI support which is enabled by default.
-        // http://stackoverflow.com/questions/7615645/ssl-handshake-alert-unrecognized-name-error-since-upgrade-to-java-1-7-0
-        System.setProperty("jsse.enableSNIExtension", "false");
 
         List<URL> URLs = new ArrayList<URL>();
         URLs.add(new URL(PACKAGES_XML));
@@ -506,7 +503,7 @@ public class PackageManager {
             // grab file from URL
             String zipFile = dirName + "/" + thisPkg.getName() + ".zip";
             FileOutputStream fos = new FileOutputStream(zipFile);
-            fos.getChannel().transferFrom(rbc, 0, 1 << 24);
+            fos.getChannel().transferFrom(rbc, 0, Long.MAX_VALUE);
 
             // unzip archive
             doUnzip(zipFile, dirName);
@@ -1702,6 +1699,43 @@ public class PackageManager {
         return result;
     }
 
+    /**
+     * @param parent          The parent class that can be an interface.
+     * @param includeParent   if true, then return the parent class itself
+     * @return    a list of classes inherited from the parent class (interface).
+     *            If those classes cannot be found in the class path,
+     *            they will be ignored (ClassNotFoundException handled inside the method).
+     */
+    public static List<Class<?>> find(Class<?> parent, boolean includeParent) {
+
+        if (all_classes == null) {
+            loadAllClasses();
+        }
+
+        List<Class<?>> result = new ArrayList<Class<?>>();
+        for (int i = all_classes.size() - 1; i >= 0; i--) {
+            String className = all_classes.get(i);
+            if (className.indexOf('/') >= 0) {
+                className = className.replaceAll("/", ".");
+            }
+            //Log.debug.println(className);
+            try {
+                Class<?> cls = BEASTClassLoader.forName(className);
+
+                if (parent.isAssignableFrom(cls)) {
+                    if (includeParent || !cls.equals(parent)) {
+                        result.add(cls);
+                    }
+                }
+            } catch (ClassNotFoundException e) {
+                Log.debug.println("Cannot find class: " + className);
+//                    e.printStackTrace();
+            }
+        }
+
+        return result;
+    }
+
 
     /*
      * Command-line interface code
