@@ -1,13 +1,18 @@
 package test.beast.integration;
 
 
+
 import java.io.File;
 import java.io.FilenameFilter;
+import java.io.IOException;
+import java.security.Permission;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.fest.swing.security.ExitException;
 import org.junit.Test;
 
+import beast.app.beastapp.BeastMain;
 import beast.core.Logger;
 import beast.core.MCMC;
 import beast.util.Randomizer;
@@ -128,6 +133,66 @@ public class ExampleXmlParsingTest extends TestCase {
         }
     } // test_ThatXmlExamplesRun
 
+    
+    protected static class ExitException extends SecurityException 
+    {
+        public final int status;
+        public ExitException(int status) 
+        {
+            super("There is no escape!");
+            this.status = status;
+        }
+    }
+    
+    @Test
+    public void test_ThatParameterisedXmlExamplesRuns() throws IOException {
+        String dir = System.getProperty("user.dir") + "/examples/parameterised";
+        Logger.FILE_MODE = Logger.LogFileMode.overwrite;
+        System.out.println("Test that parameterised XML example runs in " + dir + "/RSV2.xml");
+        Randomizer.setSeed(127);
+        
+        // prevent System.exit() having an effect
+        final SecurityManager securityManager = new SecurityManager() {
+            @Override
+            public void checkPermission( Permission permission ) {
+              if( "exitVM".equals( permission.getName() ) ) {
+                // throw new RuntimeException("Exit called") ;
+            	  System.err.println("Exit called");
+              }
+            }
+            @Override
+            public void checkExit(int status) 
+            {
+            	throw new ExitException(status);
+            }
+        };
+        SecurityManager sm = System.getSecurityManager();
+        System.setSecurityManager( securityManager ) ;
+          
+        try {
+        BeastMain.main(new String[]{
+        		"-D", "chainLength=1000",
+        		"-DF", dir + "/RSV2.json",
+        		"-DFout", "/tmp/RSV2.out.xml",
+        		dir + "/RSV2.xml"});
+        } catch (ExitException e) {
+        	if (e.status != 0) {
+        		e.printStackTrace();
+        		throw new RuntimeException("Exitted with status = " + e.status);
+        	}
+        }
+        
+        // reinstate System.exit() behaviour
+        System.setSecurityManager(sm) ;
+
+        if (!new File("/tmp/RSV2.out.xml").exists()) {
+    		throw new RuntimeException("Could not find file /tmp/RSV2.out.xml");
+        }
+                
+    } // test_ThatParameterisedXmlExamplesRuns
+  
+    
+    
 
     public static void main(String args[]) {
         org.junit.runner.JUnitCore.main("test.beast.integration.ExampleXmlParsingTest");
