@@ -14,6 +14,7 @@ import beast.core.BEASTInterface;
 import beast.core.BEASTObject;
 import beast.core.Input;
 import beast.core.Param;
+import beast.util.BEASTClassLoader;
 import beast.util.PackageManager;
 import junit.framework.TestCase;
 
@@ -35,7 +36,7 @@ public class InputTypeTest extends TestCase {
 		List<String> failingInputs = new ArrayList<String>();
 		for (String beastObjectName : beastObjectNames) {
 			try {
-				BEASTObject beastObject = (BEASTObject) Class.forName(beastObjectName).newInstance();
+				BEASTObject beastObject = (BEASTObject) BEASTClassLoader.forName(beastObjectName).newInstance();
 				List<Input<?>> inputs = beastObject.listInputs();
 				for (Input<?> input : inputs) {
 					if (input.getType() == null) {
@@ -71,7 +72,7 @@ public class InputTypeTest extends TestCase {
 		List<String> failingInputs = new ArrayList<String>();
 		for (String beastObject : beastObjectNames) {
 			try {
-				Class<?> _class = Class.forName(beastObject);
+				Class<?> _class = BEASTClassLoader.forName(beastObject);
 			    Constructor<?>[] allConstructors = _class.getDeclaredConstructors();
 			    for (Constructor<?> ctor : allConstructors) {
 			    	Annotation[][] annotations = ctor.getParameterAnnotations();
@@ -108,7 +109,7 @@ public class InputTypeTest extends TestCase {
 								case "double" : type = Double.class; break;
 								case "boolean" : type = Boolean.class; break;
 								default:
-									clazz = Class.forName(typeName);
+									clazz = BEASTClassLoader.forName(typeName);
 					    			if (clazz.isAssignableFrom(List.class)) {
 				                        Type[] genericTypes2 = ((ParameterizedType) gtypes[i + offset]).getActualTypeArguments();
 				                        type = (Class<?>) genericTypes2[0];
