@@ -4,7 +4,6 @@ import org.junit.Assert;
 import org.junit.Test;
 
 import beast.util.TreeParser;
-import org.omg.CORBA.OBJ_ADAPTER;
 
 public class TreeParserTest {
 
@@ -99,7 +98,7 @@ public class TreeParserTest {
     }
 
     @Test
-    public void testMultifurcations() throws Exception {
+    public void testBinarization() throws Exception {
 
         String newick = "((A:1.0,B:1.0,C:1.0):1.0,(D:1.0,E:1.0,F:1.0,G:1.0):1.0):0.0;";
         String binaryNewick = "((A:1.0,(B:1.0,C:1.0):0.0):1.0,(D:1.0,(E:1.0,(F:1.0,G:1.0):0.0):0.0):1.0):0.0;";
@@ -111,6 +110,31 @@ public class TreeParserTest {
 
     }
 
+    @Test
+    public void testMultifurcations() throws Exception {
+
+        String newick = "((A:1.0,B:1.0,C:1.0):1.0,(D:1.0,E:1.0,F:1.0,G:1.0):1.0):0.0;";
+
+        boolean isLabeled = true;
+
+        TreeParser treeParser = new TreeParser(newick, false, false, isLabeled, 1, false);
+        Assert.assertEquals(newick.split(";")[0], treeParser.getRoot().toNewick());
+
+    }
+
+    @Test
+    public void testMultipleMetadata() throws Exception {
+
+        String newick = "((A:1.0,B[&key=2.0,rate=3,type='OK']:1.0):1.0,(C:1.0,D:1.0):1.0):0.0;";
+
+        boolean isLabeled = true;
+
+        TreeParser treeParser = new TreeParser(newick, false, false, isLabeled, 1);
+        Assert.assertTrue(treeParser.getNode(1).getMetaData("key").equals(2.0));
+        Assert.assertTrue(treeParser.getNode(1).getMetaData("rate").equals(3.0));
+        Assert.assertTrue(treeParser.getNode(1).getMetaData("type").equals("OK"));
+    }
+
     @Test
     public void testVectorMetadata() throws Exception {
 
@@ -124,4 +148,30 @@ public class TreeParserTest {
 
     }
 
+    @Test
+    public void testNodeLengthMetadata() throws Exception {
+
+        String newick = "((A:1.0,B[&key=42]:[&key=2.5]1.0):1.0,(C:1.0,D:1.0):1.0):0.0;";
+
+        boolean isLabeled = true;
+
+        TreeParser treeParser = new TreeParser(newick, false, false, isLabeled, 1);
+        Assert.assertTrue(treeParser.getNode(1).getLengthMetaData("key").equals(2.5));
+        Assert.assertTrue(treeParser.getNode(1).getMetaData("key").equals(42.0));
+    }
+
+    @Test
+    public void testInternalNodeLabels() throws Exception {
+
+        String newick = "((xmr),((knw)ctm));";
+
+        boolean isLabeled = true;
+
+        TreeParser treeParser = new TreeParser(newick,false, true, isLabeled, 0, false);
+
+        Assert.assertTrue(treeParser.getNode(0).getID().equals("knw"));
+        Assert.assertTrue(treeParser.getNode(1).getID().equals("xmr"));
+        Assert.assertTrue(treeParser.getNode(0).getParent().getID().equals("ctm"));
+        Assert.assertTrue(treeParser.getNode(1).getParent().getID() == null);
+    }
 }
